@@ -15,12 +15,14 @@ Tensor <- R7Class(
       if (is.null(dtype)) {
         
         if (is.integer(data)) {
-          dtype <- torch_int()
+          dtype <- torch_long()
+        } else if (bit64::is.integer64(data)) {
+          dtype <- torch_long()
         } else if (is.double(data)) {
           dtype <- torch_float() # default to float
         } else if (is.logical(data)) {
           dtype <- torch_bool()
-        }
+        } 
         
       }
       
@@ -36,7 +38,7 @@ Tensor <- R7Class(
       
       
       self$ptr <- cpp_torch_tensor(data, rev(dimension), options$ptr, 
-                                   requires_grad)
+                                   requires_grad, inherits(data, "integer64"))
     },
     print = function() {
       cat(sprintf("torch_tensor \n"))
@@ -154,6 +156,23 @@ as.array.torch_tensor <- function(x, ...) {
   as_array(x)
 }
 
+as_array_impl <- function(x) {
+  a <- cpp_as_array(x$ptr)
+  
+  if (length(a$dim) <= 1L) {
+    out <- a$vec
+  } else if (length(a$dim) == 2L) {
+    out <- t(matrix(a$vec, ncol = a$dim[1], nrow = a$dim[2]))
+  } else {
+    out <- aperm(array(a$vec, dim = rev(a$dim)), seq(length(a$dim), 1))
+  }
+  
+  if (x$dtype() == torch_long() && !inherits(out, "integer64"))
+    class(out) <- c(class(out), "integer64")
+  
+  out
+}
+
 #' @export
 as_array.torch_tensor <- function(x) {
   
@@ -164,15 +183,11 @@ as_array.torch_tensor <- function(x) {
   if (x$is_quantized())
     x <- x$dequantize()
   
-  a <- cpp_as_array(x$ptr)
+  # auto convert to int32 if long.
+  if (x$dtype() == torch_long())
+    x <- x$to(dtype = torch_int32())
   
-  if (length(a$dim) <= 1L) {
-    out <- a$vec
-  } else if (length(a$dim) == 2L) {
-    out <- t(matrix(a$vec, ncol = a$dim[1], nrow = a$dim[2]))
-  } else {
-    out <- aperm(array(a$vec, dim = rev(a$dim)), seq(length(a$dim), 1))
-  }
+  out <- as_array_impl(x)
   
   out
 }
@@ -185,3 +200,9 @@ is_undefined_tensor <- function(x) {
   cpp_tensor_is_undefined(x$ptr)
 }
 
+#' @importFrom bit64 as.integer64
+#' @export
+as.integer64.torch_tensor <- function(x, keep.names = FALSE, ...) {
+  x <- x$to(dtype = torch_long())
+  as_array_impl(x)
+}
\ No newline at end of file
